from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class UploadSessionTypeField(str, Enum):
    UPLOAD_SESSION = 'upload_session'


class UploadSessionSessionEndpointsField(BaseObject):
    def __init__(
        self,
        *,
        upload_part: Optional[str] = None,
        commit: Optional[str] = None,
        abort: Optional[str] = None,
        list_parts: Optional[str] = None,
        status: Optional[str] = None,
        log_event: Optional[str] = None,
        **kwargs
    ):
        """
        :param upload_part: The URL to upload parts to., defaults to None
        :type upload_part: Optional[str], optional
        :param commit: The URL used to commit the file., defaults to None
        :type commit: Optional[str], optional
        :param abort: The URL for used to abort the session., defaults to None
        :type abort: Optional[str], optional
        :param list_parts: The URL users to list all parts., defaults to None
        :type list_parts: Optional[str], optional
        :param status: The URL used to get the status of the upload., defaults to None
        :type status: Optional[str], optional
        :param log_event: The URL used to get the upload log from., defaults to None
        :type log_event: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.upload_part = upload_part
        self.commit = commit
        self.abort = abort
        self.list_parts = list_parts
        self.status = status
        self.log_event = log_event


class UploadSession(BaseObject):
    _discriminator = 'type', {'upload_session'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[UploadSessionTypeField] = None,
        session_expires_at: Optional[DateTime] = None,
        part_size: Optional[int] = None,
        total_parts: Optional[int] = None,
        num_parts_processed: Optional[int] = None,
        session_endpoints: Optional[UploadSessionSessionEndpointsField] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for this session., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `upload_session`., defaults to None
                :type type: Optional[UploadSessionTypeField], optional
                :param session_expires_at: The date and time when this session expires., defaults to None
                :type session_expires_at: Optional[DateTime], optional
                :param part_size: The  size in bytes that must be used for all parts of of the
        upload.

        Only the last part is allowed to be of a smaller size., defaults to None
                :type part_size: Optional[int], optional
                :param total_parts: The total number of parts expected in this upload session,
        as determined by the file size and part size., defaults to None
                :type total_parts: Optional[int], optional
                :param num_parts_processed: The number of parts that have been uploaded and processed
        by the server. This starts at `0`.

        When committing a file files, inspecting this property can
        provide insight if all parts have been uploaded correctly., defaults to None
                :type num_parts_processed: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.session_expires_at = session_expires_at
        self.part_size = part_size
        self.total_parts = total_parts
        self.num_parts_processed = num_parts_processed
        self.session_endpoints = session_endpoints



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class AiAgentReferenceTypeField(str, Enum):
    AI_AGENT_ID = 'ai_agent_id'


class AiAgentReference(BaseObject):
    _discriminator = 'type', {'ai_agent_id'}

    def __init__(
        self,
        *,
        type: AiAgentReferenceTypeField = AiAgentReferenceTypeField.AI_AGENT_ID,
        id: Optional[str] = None,
        **kwargs
    ):
        """
                :param type: The type of AI agent used to handle queries., defaults to AiAgentReferenceTypeField.AI_AGENT_ID
                :type type: AiAgentReferenceTypeField, optional
                :param id: The ID of an Agent. This can be a numeric ID for custom agents (for example, `14031`)
        or a unique identifier for pre-built agents (for example, `enhanced_extract_agent`
        for the [Enhanced Extract Agent](https://developer.box.com/guides/box-ai/ai-tutorials/extract-metadata-structured#enhanced-extract-agent))., defaults to None
                :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id



from enum import Enum

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ShieldListContentEmailV2025R0TypeField(str, Enum):
    EMAIL = 'email'


class ShieldListContentEmailV2025R0(BaseObject):
    _discriminator = 'type', {'email'}

    def __init__(
        self,
        email_addresses: List[str],
        *,
        type: ShieldListContentEmailV2025R0TypeField = ShieldListContentEmailV2025R0TypeField.EMAIL,
        **kwargs
    ):
        """
        :param email_addresses: List of emails.
        :type email_addresses: List[str]
        :param type: The type of content in the shield list., defaults to ShieldListContentEmailV2025R0TypeField.EMAIL
        :type type: ShieldListContentEmailV2025R0TypeField, optional
        """
        super().__init__(**kwargs)
        self.email_addresses = email_addresses
        self.type = type



from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.integration_mapping_partner_item_teams_create_request import (
    IntegrationMappingPartnerItemTeamsCreateRequest,
)

from box_sdk_gen.schemas.folder_reference import FolderReference

from box_sdk_gen.box.errors import BoxSDKError


class IntegrationMappingTeamsCreateRequest(BaseObject):
    def __init__(
        self,
        partner_item: IntegrationMappingPartnerItemTeamsCreateRequest,
        box_item: FolderReference,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.partner_item = partner_item
        self.box_item = box_item



from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.folder_full import FolderFull

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class TransferOwnedFolderOwnedBy(BaseObject):
    def __init__(self, id: str, **kwargs):
        """
                :param id: The ID of the user who the folder will be
        transferred to.
                :type id: str
        """
        super().__init__(**kwargs)
        self.id = id


class TransferManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def transfer_owned_folder(
        self,
        user_id: str,
        owned_by: TransferOwnedFolderOwnedBy,
        *,
        fields: Optional[List[str]] = None,
        notify: Optional[bool] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FolderFull:
        """
                Move all of the items (files, folders and workflows) owned by a user into

                another user's account.


                Only the root folder (`0`) can be transferred.


                Folders can only be moved across users by users with administrative


                permissions.


                All existing shared links and folder-level collaborations are transferred


                during the operation. Please note that while collaborations at the individual


                file-level are transferred during the operation, the collaborations are


                deleted when the original user is deleted.


                If the user has a large number of items across all folders, the call will


                be run asynchronously. If the operation is not completed within 10 minutes,


                the user will receive a 200 OK response, and the operation will continue running.


                If the destination path has a metadata cascade policy attached to any of


                the parent folders, a metadata cascade operation will be kicked off


                asynchronously.


                There is currently no way to check for when this operation is finished.


                The destination folder's name will be in the format `{User}'s Files and


                Folders`, where `{User}` is the display name of the user.


                To make this API call your application will need to have the "Read and write


                all files and folders stored in Box" scope enabled.


                Please make sure the destination user has access to `Relay` or `Relay Lite`,


                and has access to the files and folders involved in the workflows being


                transferred.


                Admins will receive an email when the operation is completed.

                :param user_id: The ID of the user.
        Example: "12345"
                :type user_id: str
                :param owned_by: The user who the folder will be transferred to.
                :type owned_by: TransferOwnedFolderOwnedBy
                :param fields: A comma-separated list of attributes to include in the
        response. This can be used to request fields that are
        not normally returned in a standard response.

        Be aware that specifying this parameter will have the
        effect that none of the standard fields are returned in
        the response unless explicitly specified, instead only
        fields for the mini representation are returned, additional
        to the fields requested., defaults to None
                :type fields: Optional[List[str]], optional
                :param notify: Determines if users should receive email notification
        for the action performed., defaults to None
                :type notify: Optional[bool], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'owned_by': owned_by}
        query_params_map: Dict[str, str] = prepare_params(
            {'fields': to_string(fields), 'notify': to_string(notify)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/users/',
                        to_string(user_id),
                        '/folders/0',
                    ]
                ),
                method='PUT',
                params=query_params_map,
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FolderFull)



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.schemas.user_base import UserBaseTypeField

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.user import UserStatusField

from box_sdk_gen.schemas.user import UserNotificationEmailField

from box_sdk_gen.schemas.user import User

from box_sdk_gen.schemas.tracking_code import TrackingCode

from box_sdk_gen.box.errors import BoxSDKError


class UserFullRoleField(str, Enum):
    ADMIN = 'admin'
    COADMIN = 'coadmin'
    USER = 'user'


class UserFullEnterpriseTypeField(str, Enum):
    ENTERPRISE = 'enterprise'


class UserFullEnterpriseField(BaseObject):
    _discriminator = 'type', {'enterprise'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[UserFullEnterpriseTypeField] = None,
        name: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this enterprise., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `enterprise`., defaults to None
        :type type: Optional[UserFullEnterpriseTypeField], optional
        :param name: The name of the enterprise., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name


class UserFull(User):
    def __init__(
        self,
        id: str,
        *,
        role: Optional[UserFullRoleField] = None,
        tracking_codes: Optional[List[TrackingCode]] = None,
        can_see_managed_users: Optional[bool] = None,
        is_sync_enabled: Optional[bool] = None,
        is_external_collab_restricted: Optional[bool] = None,
        is_exempt_from_device_limits: Optional[bool] = None,
        is_exempt_from_login_verification: Optional[bool] = None,
        enterprise: Optional[UserFullEnterpriseField] = None,
        my_tags: Optional[List[str]] = None,
        hostname: Optional[str] = None,
        is_platform_access_only: Optional[bool] = None,
        external_app_user_id: Optional[str] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        language: Optional[str] = None,
        timezone: Optional[str] = None,
        space_amount: Optional[int] = None,
        space_used: Optional[int] = None,
        max_upload_size: Optional[int] = None,
        status: Optional[UserStatusField] = None,
        job_title: Optional[str] = None,
        phone: Optional[str] = None,
        address: Optional[str] = None,
        avatar_url: Optional[str] = None,
        notification_email: Optional[UserNotificationEmailField] = None,
        name: Optional[str] = None,
        login: Optional[str] = None,
        type: UserBaseTypeField = UserBaseTypeField.USER,
        **kwargs
    ):
        """
                :param id: The unique identifier for this user.
                :type id: str
                :param role: The user’s enterprise role., defaults to None
                :type role: Optional[UserFullRoleField], optional
                :param tracking_codes: Tracking codes allow an admin to generate reports from the
        admin console and assign an attribute to a specific group
        of users. This setting must be enabled for an enterprise
        before it can be used., defaults to None
                :type tracking_codes: Optional[List[TrackingCode]], optional
                :param can_see_managed_users: Whether the user can see other enterprise users in their contact list., defaults to None
                :type can_see_managed_users: Optional[bool], optional
                :param is_sync_enabled: Whether the user can use Box Sync., defaults to None
                :type is_sync_enabled: Optional[bool], optional
                :param is_external_collab_restricted: Whether the user is allowed to collaborate with users outside their
        enterprise., defaults to None
                :type is_external_collab_restricted: Optional[bool], optional
                :param is_exempt_from_device_limits: Whether to exempt the user from Enterprise device limits., defaults to None
                :type is_exempt_from_device_limits: Optional[bool], optional
                :param is_exempt_from_login_verification: Whether the user must use two-factor authentication., defaults to None
                :type is_exempt_from_login_verification: Optional[bool], optional
                :param my_tags: Tags for all files and folders owned by the user. Values returned
        will only contain tags that were set by the requester., defaults to None
                :type my_tags: Optional[List[str]], optional
                :param hostname: The root (protocol, subdomain, domain) of any links that need to be
        generated for the user., defaults to None
                :type hostname: Optional[str], optional
                :param is_platform_access_only: Whether the user is an App User., defaults to None
                :type is_platform_access_only: Optional[bool], optional
                :param external_app_user_id: An external identifier for an app user, which can be used to look up
        the user. This can be used to tie user IDs from external identity
        providers to Box users., defaults to None
                :type external_app_user_id: Optional[str], optional
                :param created_at: When the user object was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: When the user object was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param language: The language of the user, formatted in modified version of the
        [ISO 639-1](https://developer.box.com/guides/api-calls/language-codes) format., defaults to None
                :type language: Optional[str], optional
                :param timezone: The user's timezone., defaults to None
                :type timezone: Optional[str], optional
                :param space_amount: The user’s total available space amount in bytes., defaults to None
                :type space_amount: Optional[int], optional
                :param space_used: The amount of space in use by the user., defaults to None
                :type space_used: Optional[int], optional
                :param max_upload_size: The maximum individual file size in bytes the user can have., defaults to None
                :type max_upload_size: Optional[int], optional
                :param status: The user's account status., defaults to None
                :type status: Optional[UserStatusField], optional
                :param job_title: The user’s job title., defaults to None
                :type job_title: Optional[str], optional
                :param phone: The user’s phone number., defaults to None
                :type phone: Optional[str], optional
                :param address: The user’s address., defaults to None
                :type address: Optional[str], optional
                :param avatar_url: URL of the user’s avatar image., defaults to None
                :type avatar_url: Optional[str], optional
                :param notification_email: An alternate notification email address to which email
        notifications are sent. When it's confirmed, this will be
        the email address to which notifications are sent instead of
        to the primary email address., defaults to None
                :type notification_email: Optional[UserNotificationEmailField], optional
                :param name: The display name of this user., defaults to None
                :type name: Optional[str], optional
                :param login: The primary email address of this user., defaults to None
                :type login: Optional[str], optional
                :param type: The value will always be `user`., defaults to UserBaseTypeField.USER
                :type type: UserBaseTypeField, optional
        """
        super().__init__(
            id=id,
            created_at=created_at,
            modified_at=modified_at,
            language=language,
            timezone=timezone,
            space_amount=space_amount,
            space_used=space_used,
            max_upload_size=max_upload_size,
            status=status,
            job_title=job_title,
            phone=phone,
            address=address,
            avatar_url=avatar_url,
            notification_email=notification_email,
            name=name,
            login=login,
            type=type,
            **kwargs
        )
        self.role = role
        self.tracking_codes = tracking_codes
        self.can_see_managed_users = can_see_managed_users
        self.is_sync_enabled = is_sync_enabled
        self.is_external_collab_restricted = is_external_collab_restricted
        self.is_exempt_from_device_limits = is_exempt_from_device_limits
        self.is_exempt_from_login_verification = is_exempt_from_login_verification
        self.enterprise = enterprise
        self.my_tags = my_tags
        self.hostname = hostname
        self.is_platform_access_only = is_platform_access_only
        self.external_app_user_id = external_app_user_id



from enum import Enum

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from typing import List

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.classification import Classification

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class UpdateClassificationOnFolderRequestBodyOpField(str, Enum):
    REPLACE = 'replace'


class UpdateClassificationOnFolderRequestBodyPathField(str, Enum):
    _BOX__SECURITY__CLASSIFICATION__KEY = '/Box__Security__Classification__Key'


class UpdateClassificationOnFolderRequestBody(BaseObject):
    def __init__(
        self,
        value: str,
        *,
        op: UpdateClassificationOnFolderRequestBodyOpField = UpdateClassificationOnFolderRequestBodyOpField.REPLACE,
        path: UpdateClassificationOnFolderRequestBodyPathField = UpdateClassificationOnFolderRequestBodyPathField._BOX__SECURITY__CLASSIFICATION__KEY,
        **kwargs
    ):
        """
                :param value: The name of the classification to apply to this folder.

        To list the available classifications in an enterprise,
        use the classification API to retrieve the
        [classification template](https://developer.box.com/reference/get-metadata-templates-enterprise-securityClassification-6VMVochwUWo-schema)
        which lists all available classification keys.
                :type value: str
                :param op: The value will always be `replace`., defaults to UpdateClassificationOnFolderRequestBodyOpField.REPLACE
                :type op: UpdateClassificationOnFolderRequestBodyOpField, optional
                :param path: Defines classifications
        available in the enterprise., defaults to UpdateClassificationOnFolderRequestBodyPathField._BOX__SECURITY__CLASSIFICATION__KEY
                :type path: UpdateClassificationOnFolderRequestBodyPathField, optional
        """
        super().__init__(**kwargs)
        self.value = value
        self.op = op
        self.path = path


class FolderClassificationsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_classification_on_folder(
        self,
        folder_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Classification:
        """
                Retrieves the classification metadata instance that

                has been applied to a folder.


                This API can also be called by including the enterprise ID in the


                URL explicitly, for example


                `/folders/:id/enterprise_12345/securityClassification-6VMVochwUWo`.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/metadata/enterprise/securityClassification-6VMVochwUWo',
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Classification)

    def add_classification_to_folder(
        self,
        folder_id: str,
        *,
        box_security_classification_key: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Classification:
        """
                Adds a classification to a folder by specifying the label of the

                classification to add.


                This API can also be called by including the enterprise ID in the


                URL explicitly, for example


                `/folders/:id/enterprise_12345/securityClassification-6VMVochwUWo`.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param box_security_classification_key: The name of the classification to apply to this folder.

        To list the available classifications in an enterprise,
        use the classification API to retrieve the
        [classification template](https://developer.box.com/reference/get-metadata-templates-enterprise-securityClassification-6VMVochwUWo-schema)
        which lists all available classification keys., defaults to None
                :type box_security_classification_key: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'Box__Security__Classification__Key': box_security_classification_key
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/metadata/enterprise/securityClassification-6VMVochwUWo',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Classification)

    def update_classification_on_folder(
        self,
        folder_id: str,
        request_body: List[UpdateClassificationOnFolderRequestBody],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Classification:
        """
                Updates a classification on a folder.

                The classification can only be updated if a classification has already been


                applied to the folder before. When editing classifications, only values are


                defined for the enterprise will be accepted.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param request_body: Request body of updateClassificationOnFolder method
                :type request_body: List[UpdateClassificationOnFolderRequestBody]
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/metadata/enterprise/securityClassification-6VMVochwUWo',
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json-patch+json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Classification)

    def delete_classification_from_folder(
        self,
        folder_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Removes any classifications from a folder.

                This API can also be called by including the enterprise ID in the


                URL explicitly, for example


                `/folders/:id/enterprise_12345/securityClassification-6VMVochwUWo`.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
        Example: "12345"
                :type folder_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folders/',
                        to_string(folder_id),
                        '/metadata/enterprise/securityClassification-6VMVochwUWo',
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from typing import Union

from box_sdk_gen.schemas.file_full import FileFull

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.box.errors import BoxSDKError

Item = Union[FileFull, FolderMini, WebLink]



from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from box_sdk_gen.serialization.json import deserialize

from typing import List

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenGrantTypeField

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2TokenSubjectTokenTypeField

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.schemas.access_token import AccessToken

from box_sdk_gen.schemas.post_o_auth_2_token import PostOAuth2Token

from box_sdk_gen.schemas.post_o_auth_2_revoke import PostOAuth2Revoke

from box_sdk_gen.box.token_storage import TokenStorage

from box_sdk_gen.box.token_storage import InMemoryTokenStorage

from box_sdk_gen.serialization.json import json_to_serialized_data

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.internal.utils import get_uuid

from box_sdk_gen.internal.utils import read_text_from_file

from box_sdk_gen.internal.utils import is_browser

from box_sdk_gen.internal.utils import get_epoch_time_in_seconds

from box_sdk_gen.internal.utils import create_jwt_assertion

from box_sdk_gen.internal.utils import JwtSignOptions

from box_sdk_gen.internal.utils import JwtKey

from box_sdk_gen.internal.utils import JwtAlgorithm

from box_sdk_gen.internal.utils import PrivateKeyDecryptor

from box_sdk_gen.internal.utils import DefaultPrivateKeyDecryptor

from box_sdk_gen.managers.authorization import AuthorizationManager

from box_sdk_gen.box.errors import BoxSDKError


class JwtConfigAppSettingsAppAuth(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'public_key_id': 'publicKeyID',
        'private_key': 'privateKey',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'publicKeyID': 'public_key_id',
        'privateKey': 'private_key',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(self, public_key_id: str, private_key: str, passphrase: str, **kwargs):
        """
        :param public_key_id: Public key ID
        :type public_key_id: str
        :param private_key: Private key
        :type private_key: str
        :param passphrase: Passphrase
        :type passphrase: str
        """
        super().__init__(**kwargs)
        self.public_key_id = public_key_id
        self.private_key = private_key
        self.passphrase = passphrase


class JwtConfigAppSettings(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'client_id': 'clientID',
        'client_secret': 'clientSecret',
        'app_auth': 'appAuth',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'clientID': 'client_id',
        'clientSecret': 'client_secret',
        'appAuth': 'app_auth',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        client_id: str,
        client_secret: str,
        app_auth: JwtConfigAppSettingsAppAuth,
        **kwargs
    ):
        """
        :param client_id: App client ID
        :type client_id: str
        :param client_secret: App client secret
        :type client_secret: str
        :param app_auth: App auth settings
        :type app_auth: JwtConfigAppSettingsAppAuth
        """
        super().__init__(**kwargs)
        self.client_id = client_id
        self.client_secret = client_secret
        self.app_auth = app_auth


class JwtConfigFile(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'enterprise_id': 'enterpriseID',
        'user_id': 'userID',
        'box_app_settings': 'boxAppSettings',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'enterpriseID': 'enterprise_id',
        'userID': 'user_id',
        'boxAppSettings': 'box_app_settings',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        box_app_settings: JwtConfigAppSettings,
        *,
        enterprise_id: Optional[str] = None,
        user_id: Optional[str] = None,
        **kwargs
    ):
        """
        :param box_app_settings: App settings
        :type box_app_settings: JwtConfigAppSettings
        :param enterprise_id: Enterprise ID, defaults to None
        :type enterprise_id: Optional[str], optional
        :param user_id: User ID, defaults to None
        :type user_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.box_app_settings = box_app_settings
        self.enterprise_id = enterprise_id
        self.user_id = user_id


class JWTConfig:
    def __init__(
        self,
        client_id: str,
        client_secret: str,
        jwt_key_id: str,
        private_key: str,
        private_key_passphrase: str,
        *,
        enterprise_id: Optional[str] = None,
        user_id: Optional[str] = None,
        algorithm: Optional[JwtAlgorithm] = JwtAlgorithm.RS256,
        token_storage: TokenStorage = None,
        private_key_decryptor: PrivateKeyDecryptor = None
    ):
        """
        :param client_id: App client ID
        :type client_id: str
        :param client_secret: App client secret
        :type client_secret: str
        :param jwt_key_id: Public key ID
        :type jwt_key_id: str
        :param private_key: Private key
        :type private_key: str
        :param private_key_passphrase: Passphrase
        :type private_key_passphrase: str
        :param enterprise_id: Enterprise ID, defaults to None
        :type enterprise_id: Optional[str], optional
        :param user_id: User ID, defaults to None
        :type user_id: Optional[str], optional
        """
        if token_storage is None:
            token_storage = InMemoryTokenStorage()
        if private_key_decryptor is None:
            private_key_decryptor = DefaultPrivateKeyDecryptor()
        self.client_id = client_id
        self.client_secret = client_secret
        self.jwt_key_id = jwt_key_id
        self.private_key = private_key
        self.private_key_passphrase = private_key_passphrase
        self.enterprise_id = enterprise_id
        self.user_id = user_id
        self.algorithm = algorithm
        self.token_storage = token_storage
        self.private_key_decryptor = private_key_decryptor

    @staticmethod
    def from_config_json_string(
        config_json_string: str,
        *,
        token_storage: Optional[TokenStorage] = None,
        private_key_decryptor: Optional[PrivateKeyDecryptor] = None
    ) -> 'JWTConfig':
        """
        Create an auth instance as defined by a string content of JSON file downloaded from the Box Developer Console.

        See https://developer.box.com/en/guides/authentication/jwt/ for more information.

        :param config_json_string: String content of JSON file containing the configuration.
        :type config_json_string: str
        :param token_storage: Object responsible for storing token. If no custom implementation provided, the token will be stored in memory, defaults to None
        :type token_storage: Optional[TokenStorage], optional
        :param private_key_decryptor: Object responsible for decrypting private key for jwt auth. If no custom implementation provided, the DefaultPrivateKeyDecryptor will be used., defaults to None
        :type private_key_decryptor: Optional[PrivateKeyDecryptor], optional
        """
        config_json: JwtConfigFile = deserialize(
            json_to_serialized_data(config_json_string), JwtConfigFile
        )
        token_storage_to_use: Optional[TokenStorage] = (
            InMemoryTokenStorage() if token_storage == None else token_storage
        )
        private_key_decryptor_to_use: Optional[PrivateKeyDecryptor] = (
            DefaultPrivateKeyDecryptor()
            if private_key_decryptor == None
            else private_key_decryptor
        )
        new_config: 'JWTConfig' = JWTConfig(
            client_id=config_json.box_app_settings.client_id,
            client_secret=config_json.box_app_settings.client_secret,
            enterprise_id=config_json.enterprise_id,
            user_id=config_json.user_id,
            jwt_key_id=config_json.box_app_settings.app_auth.public_key_id,
            private_key=config_json.box_app_settings.app_auth.private_key,
            private_key_passphrase=config_json.box_app_settings.app_auth.passphrase,
            token_storage=token_storage_to_use,
            private_key_decryptor=private_key_decryptor_to_use,
        )
        return new_config

    @staticmethod
    def from_config_file(
        config_file_path: str,
        *,
        token_storage: Optional[TokenStorage] = None,
        private_key_decryptor: Optional[PrivateKeyDecryptor] = None
    ) -> 'JWTConfig':
        """
        Create an auth instance as defined by a JSON file downloaded from the Box Developer Console.

        See https://developer.box.com/en/guides/authentication/jwt/ for more information.

        :param config_file_path: Path to the JSON file containing the configuration.
        :type config_file_path: str
        :param token_storage: Object responsible for storing token. If no custom implementation provided, the token will be stored in memory., defaults to None
        :type token_storage: Optional[TokenStorage], optional
        :param private_key_decryptor: Object responsible for decrypting private key for jwt auth. If no custom implementation provided, the DefaultPrivateKeyDecryptor will be used., defaults to None
        :type private_key_decryptor: Optional[PrivateKeyDecryptor], optional
        """
        config_json_string: str = read_text_from_file(config_file_path)
        return JWTConfig.from_config_json_string(
            config_json_string,
            token_storage=token_storage,
            private_key_decryptor=private_key_decryptor,
        )


class BoxJWTAuth(Authentication):
    def __init__(self, config: JWTConfig, **kwargs):
        """
        :param config: An object containing all JWT configuration to use for authentication
        :type config: JWTConfig
        """
        super().__init__(**kwargs)
        self.config = config
        self.token_storage = self.config.token_storage
        self.subject_id = (
            self.config.enterprise_id
            if not self.config.enterprise_id == None
            else self.config.user_id
        )
        self.subject_type = (
            'enterprise' if not self.config.enterprise_id == None else 'user'
        )

    def refresh_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Get new access token using JWT auth.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        if is_browser():
            raise BoxSDKError(
                message='JWT auth is not supported in browser environment.'
            )
        alg: JwtAlgorithm = (
            self.config.algorithm
            if not self.config.algorithm == None
            else JwtAlgorithm.RS256
        )
        claims: Dict = {
            'exp': get_epoch_time_in_seconds() + 30,
            'box_sub_type': self.subject_type,
        }
        jwt_options: JwtSignOptions = JwtSignOptions(
            algorithm=alg,
            audience='https://api.box.com/oauth2/token',
            subject=self.subject_id,
            issuer=self.config.client_id,
            jwtid=get_uuid(),
            keyid=self.config.jwt_key_id,
            private_key_decryptor=self.config.private_key_decryptor,
        )
        jwt_key: JwtKey = JwtKey(
            key=self.config.private_key, passphrase=self.config.private_key_passphrase
        )
        assertion: str = create_jwt_assertion(claims, jwt_key, jwt_options)
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.URN_IETF_PARAMS_OAUTH_GRANT_TYPE_JWT_BEARER,
            assertion=assertion,
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
        )
        self.token_storage.store(token)
        return token

    def retrieve_token(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Get the current access token. If the current access token is expired or not found, this method will attempt to refresh the token.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        old_token: Optional[AccessToken] = self.token_storage.get()
        if old_token == None:
            new_token: AccessToken = self.refresh_token(network_session=network_session)
            return new_token
        return old_token

    def retrieve_authorization_header(
        self, *, network_session: Optional[NetworkSession] = None
    ) -> str:
        token: AccessToken = self.retrieve_token(network_session=network_session)
        return ''.join(['Bearer ', token.access_token])

    def with_user_subject(
        self, user_id: str, *, token_storage: TokenStorage = None
    ) -> 'BoxJWTAuth':
        """
        Create a new BoxJWTAuth instance that uses the provided user ID as the subject of the JWT assertion.

        May be one of this application's created App User. Depending on the configured User Access Level, may also be any other App User or Managed User in the enterprise.


        <https://developer.box.com/en/guides/applications/>


        <https://developer.box.com/en/guides/authentication/select/>

        :param user_id: The id of the user to authenticate
        :type user_id: str
        :param token_storage: Object responsible for storing token in newly created BoxJWTAuth. If no custom implementation provided, the token will be stored in memory., defaults to None
        :type token_storage: TokenStorage, optional
        """
        if token_storage is None:
            token_storage = InMemoryTokenStorage()
        new_config: JWTConfig = JWTConfig(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            enterprise_id=None,
            user_id=user_id,
            jwt_key_id=self.config.jwt_key_id,
            private_key=self.config.private_key,
            private_key_passphrase=self.config.private_key_passphrase,
            token_storage=token_storage,
        )
        new_auth: 'BoxJWTAuth' = BoxJWTAuth(config=new_config)
        return new_auth

    def with_enterprise_subject(
        self, enterprise_id: str, *, token_storage: TokenStorage = None
    ) -> 'BoxJWTAuth':
        """
        Create a new BoxJWTAuth instance that uses the provided enterprise ID as the subject of the JWT assertion.
        :param enterprise_id: The id of the enterprise to authenticate
        :type enterprise_id: str
        :param token_storage: Object responsible for storing token in newly created BoxJWTAuth. If no custom implementation provided, the token will be stored in memory., defaults to None
        :type token_storage: TokenStorage, optional
        """
        if token_storage is None:
            token_storage = InMemoryTokenStorage()
        new_config: JWTConfig = JWTConfig(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            enterprise_id=enterprise_id,
            user_id=None,
            jwt_key_id=self.config.jwt_key_id,
            private_key=self.config.private_key,
            private_key_passphrase=self.config.private_key_passphrase,
            token_storage=token_storage,
        )
        new_auth: 'BoxJWTAuth' = BoxJWTAuth(config=new_config)
        return new_auth

    def downscope_token(
        self,
        scopes: List[str],
        *,
        resource: Optional[str] = None,
        shared_link: Optional[str] = None,
        network_session: Optional[NetworkSession] = None
    ) -> AccessToken:
        """
        Downscope access token to the provided scopes. Returning a new access token with the provided scopes, with the original access token unchanged.
        :param scopes: The scope(s) to apply to the resulting token.
        :type scopes: List[str]
        :param resource: The file or folder to get a downscoped token for. If None and shared_link None, the resulting token will not be scoped down to just a single item. The resource should be a full URL to an item, e.g. https://api.box.com/2.0/files/123456., defaults to None
        :type resource: Optional[str], optional
        :param shared_link: The shared link to get a downscoped token for. If None and item None, the resulting token will not be scoped down to just a single item., defaults to None
        :type shared_link: Optional[str], optional
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        token: Optional[AccessToken] = self.retrieve_token(
            network_session=network_session
        )
        if token == None:
            raise BoxSDKError(
                message='No access token is available. Make an API call to retrieve a token before calling this method.'
            )
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        downscoped_token: AccessToken = auth_manager.request_access_token(
            PostOAuth2TokenGrantTypeField.URN_IETF_PARAMS_OAUTH_GRANT_TYPE_TOKEN_EXCHANGE,
            subject_token=token.access_token,
            subject_token_type=PostOAuth2TokenSubjectTokenTypeField.URN_IETF_PARAMS_OAUTH_TOKEN_TYPE_ACCESS_TOKEN,
            resource=resource,
            scope=' '.join(scopes),
            box_shared_link=shared_link,
        )
        return downscoped_token

    def revoke_token(self, *, network_session: Optional[NetworkSession] = None) -> None:
        """
        Revoke the current access token and remove it from token storage.
        :param network_session: An object to keep network session state, defaults to None
        :type network_session: Optional[NetworkSession], optional
        """
        old_token: Optional[AccessToken] = self.token_storage.get()
        if old_token == None:
            return None
        auth_manager: AuthorizationManager = AuthorizationManager(
            network_session=(
                network_session if not network_session == None else NetworkSession()
            )
        )
        auth_manager.revoke_access_token(
            client_id=self.config.client_id,
            client_secret=self.config.client_secret,
            token=old_token.access_token,
        )
        self.token_storage.clear()
        return None



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class IntegrationMappingSlackOptions(BaseObject):
    def __init__(
        self, *, is_access_management_disabled: Optional[bool] = None, **kwargs
    ):
        """
                :param is_access_management_disabled: Indicates whether or not channel member
        access to the underlying box item
        should be automatically managed.
        Depending on type of channel, access is managed
        through creating collaborations or shared links., defaults to None
                :type is_access_management_disabled: Optional[bool], optional
        """
        super().__init__(**kwargs)
        self.is_access_management_disabled = is_access_management_disabled



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.v2025_r0.shield_list_mini_v2025_r0 import ShieldListMiniV2025R0

from box_sdk_gen.box.errors import BoxSDKError


class ShieldListsV2025R0(BaseObject):
    def __init__(
        self, *, entries: Optional[List[ShieldListMiniV2025R0]] = None, **kwargs
    ):
        """
        :param entries: A list of shield list objects., defaults to None
        :type entries: Optional[List[ShieldListMiniV2025R0]], optional
        """
        super().__init__(**kwargs)
        self.entries = entries



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.folder_mini import FolderMini

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError


class EventSourceItemTypeField(str, Enum):
    FILE = 'file'
    FOLDER = 'folder'


class EventSourceClassificationField(BaseObject):
    def __init__(self, *, name: Optional[str] = None, **kwargs):
        """
        :param name: The classification's name., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.name = name


class EventSource(BaseObject):
    _discriminator = 'item_type', {'file', 'folder'}

    def __init__(
        self,
        item_type: EventSourceItemTypeField,
        item_id: str,
        item_name: str,
        *,
        classification: Optional[EventSourceClassificationField] = None,
        parent: Optional[FolderMini] = None,
        owned_by: Optional[UserMini] = None,
        **kwargs
    ):
        """
                :param item_type: The type of the item that the event
        represents. Can be `file` or `folder`.
                :type item_type: EventSourceItemTypeField
                :param item_id: The unique identifier that represents the
        item.
                :type item_id: str
                :param item_name: The name of the item.
                :type item_name: str
                :param classification: The object containing classification information for the item that
        triggered the event. This field will not appear if the item does not
        have a classification set., defaults to None
                :type classification: Optional[EventSourceClassificationField], optional
        """
        super().__init__(**kwargs)
        self.item_type = item_type
        self.item_id = item_id
        self.item_name = item_name
        self.classification = classification
        self.parent = parent
        self.owned_by = owned_by



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class CollaborationAllowlistExemptTargetTypeField(str, Enum):
    COLLABORATION_WHITELIST_EXEMPT_TARGET = 'collaboration_whitelist_exempt_target'


class CollaborationAllowlistExemptTargetEnterpriseTypeField(str, Enum):
    ENTERPRISE = 'enterprise'


class CollaborationAllowlistExemptTargetEnterpriseField(BaseObject):
    _discriminator = 'type', {'enterprise'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[CollaborationAllowlistExemptTargetEnterpriseTypeField] = None,
        name: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this enterprise., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `enterprise`., defaults to None
        :type type: Optional[CollaborationAllowlistExemptTargetEnterpriseTypeField], optional
        :param name: The name of the enterprise., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.name = name


class CollaborationAllowlistExemptTarget(BaseObject):
    _discriminator = 'type', {'collaboration_whitelist_exempt_target'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[CollaborationAllowlistExemptTargetTypeField] = None,
        enterprise: Optional[CollaborationAllowlistExemptTargetEnterpriseField] = None,
        user: Optional[UserMini] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for this exemption., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `collaboration_whitelist_exempt_target`., defaults to None
        :type type: Optional[CollaborationAllowlistExemptTargetTypeField], optional
        :param created_at: The time the entry was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_at: The time the entry was modified., defaults to None
        :type modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.enterprise = enterprise
        self.user = user
        self.created_at = created_at
        self.modified_at = modified_at



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class OAuth2Error(BaseObject):
    def __init__(
        self,
        *,
        error: Optional[str] = None,
        error_description: Optional[str] = None,
        **kwargs
    ):
        """
        :param error: The type of the error returned., defaults to None
        :type error: Optional[str], optional
        :param error_description: The type of the error returned., defaults to None
        :type error_description: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.error = error
        self.error_description = error_description



from enum import Enum

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class DocGenTagV2025R0TagTypeField(str, Enum):
    TEXT = 'text'
    ARITHMETIC = 'arithmetic'
    CONDITIONAL = 'conditional'
    FOR_LOOP = 'for-loop'
    TABLE_LOOP = 'table-loop'
    IMAGE = 'image'


class DocGenTagV2025R0(BaseObject):
    def __init__(
        self,
        tag_content: str,
        tag_type: DocGenTagV2025R0TagTypeField,
        json_paths: List[str],
        **kwargs
    ):
        """
        :param tag_content: The content of the tag.
        :type tag_content: str
        :param tag_type: Type of the tag.
        :type tag_type: DocGenTagV2025R0TagTypeField
        :param json_paths: List of the paths.
        :type json_paths: List[str]
        """
        super().__init__(**kwargs)
        self.tag_content = tag_content
        self.tag_type = tag_type
        self.json_paths = json_paths



from box_sdk_gen.box.event_stream import *

from box_sdk_gen.box.errors import *

from box_sdk_gen.box.token_storage import *

from box_sdk_gen.box.developer_token_auth import *

from box_sdk_gen.box.oauth import *

from box_sdk_gen.box.jwt_auth import *

from box_sdk_gen.box.ccg_auth import *



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import List

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class TimelineSkillCardTypeField(str, Enum):
    SKILL_CARD = 'skill_card'


class TimelineSkillCardSkillCardTypeField(str, Enum):
    TIMELINE = 'timeline'


class TimelineSkillCardSkillCardTitleField(BaseObject):
    def __init__(self, message: str, *, code: Optional[str] = None, **kwargs):
        """
        :param message: The actual title to show in the UI.
        :type message: str
        :param code: An optional identifier for the title., defaults to None
        :type code: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.message = message
        self.code = code


class TimelineSkillCardSkillTypeField(str, Enum):
    SERVICE = 'service'


class TimelineSkillCardSkillField(BaseObject):
    _discriminator = 'type', {'service'}

    def __init__(
        self,
        id: str,
        *,
        type: TimelineSkillCardSkillTypeField = TimelineSkillCardSkillTypeField.SERVICE,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the service that
        applied this metadata.
                :type id: str
                :param type: The value will always be `service`., defaults to TimelineSkillCardSkillTypeField.SERVICE
                :type type: TimelineSkillCardSkillTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class TimelineSkillCardInvocationTypeField(str, Enum):
    SKILL_INVOCATION = 'skill_invocation'


class TimelineSkillCardInvocationField(BaseObject):
    _discriminator = 'type', {'skill_invocation'}

    def __init__(
        self,
        id: str,
        *,
        type: TimelineSkillCardInvocationTypeField = TimelineSkillCardInvocationTypeField.SKILL_INVOCATION,
        **kwargs
    ):
        """
                :param id: A custom identifier that represent the instance of
        the service that applied this metadata. For example,
        if your `image-recognition-service` runs on multiple
        nodes, this field can be used to identify the ID of
        the node that was used to apply the metadata.
                :type id: str
                :param type: The value will always be `skill_invocation`., defaults to TimelineSkillCardInvocationTypeField.SKILL_INVOCATION
                :type type: TimelineSkillCardInvocationTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class TimelineSkillCardEntriesAppearsField(BaseObject):
    def __init__(
        self, *, start: Optional[int] = None, end: Optional[int] = None, **kwargs
    ):
        """
                :param start: The time in seconds when an
        entry should start appearing on a timeline., defaults to None
                :type start: Optional[int], optional
                :param end: The time in seconds when an
        entry should stop appearing on a timeline., defaults to None
                :type end: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.start = start
        self.end = end


class TimelineSkillCardEntriesField(BaseObject):
    def __init__(
        self,
        *,
        text: Optional[str] = None,
        appears: Optional[List[TimelineSkillCardEntriesAppearsField]] = None,
        image_url: Optional[str] = None,
        **kwargs
    ):
        """
                :param text: The text of the entry. This would be the display
        name for an item being placed on the timeline, for example the name
        of the person who was detected in a video., defaults to None
                :type text: Optional[str], optional
                :param appears: Defines a list of timestamps for when this item should appear on the
        timeline., defaults to None
                :type appears: Optional[List[TimelineSkillCardEntriesAppearsField]], optional
                :param image_url: The image to show on a for an entry that appears
        on a timeline. This image URL is required for every entry.

        The image will be shown in a
        list of items (for example faces), and clicking
        the image will show the user where that entry
        appears during the duration of this entry., defaults to None
                :type image_url: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.text = text
        self.appears = appears
        self.image_url = image_url


class TimelineSkillCard(BaseObject):
    _discriminator = 'skill_card_type', {'timeline'}

    def __init__(
        self,
        skill: TimelineSkillCardSkillField,
        invocation: TimelineSkillCardInvocationField,
        entries: List[TimelineSkillCardEntriesField],
        *,
        created_at: Optional[DateTime] = None,
        type: TimelineSkillCardTypeField = TimelineSkillCardTypeField.SKILL_CARD,
        skill_card_type: TimelineSkillCardSkillCardTypeField = TimelineSkillCardSkillCardTypeField.TIMELINE,
        skill_card_title: Optional[TimelineSkillCardSkillCardTitleField] = None,
        duration: Optional[int] = None,
        **kwargs
    ):
        """
                :param skill: The service that applied this metadata.
                :type skill: TimelineSkillCardSkillField
                :param invocation: The invocation of this service, used to track
        which instance of a service applied the metadata.
                :type invocation: TimelineSkillCardInvocationField
                :param entries: A list of entries on the timeline.
                :type entries: List[TimelineSkillCardEntriesField]
                :param created_at: The optional date and time this card was created at., defaults to None
                :type created_at: Optional[DateTime], optional
                :param type: The value will always be `skill_card`., defaults to TimelineSkillCardTypeField.SKILL_CARD
                :type type: TimelineSkillCardTypeField, optional
                :param skill_card_type: The value will always be `timeline`., defaults to TimelineSkillCardSkillCardTypeField.TIMELINE
                :type skill_card_type: TimelineSkillCardSkillCardTypeField, optional
                :param skill_card_title: The title of the card., defaults to None
                :type skill_card_title: Optional[TimelineSkillCardSkillCardTitleField], optional
                :param duration: An total duration in seconds of the timeline., defaults to None
                :type duration: Optional[int], optional
        """
        super().__init__(**kwargs)
        self.skill = skill
        self.invocation = invocation
        self.entries = entries
        self.created_at = created_at
        self.type = type
        self.skill_card_type = skill_card_type
        self.skill_card_title = skill_card_title
        self.duration = duration



from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class DocGenTagsProcessingMessageV2025R0(BaseObject):
    def __init__(self, message: str, **kwargs):
        """
        :param message: A message informing the user that document tags are still being processed.
        :type message: str
        """
        super().__init__(**kwargs)
        self.message = message



class GeneratedCodeError(Exception):
    def __init__(self, message: str, **kwargs):
        super().__init__(message)
        self.name = 'GeneratedCodeError'
        self.message = message
        self.extra = kwargs



from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.v2025_r0.enterprise_configuration_v2025_r0 import (
    EnterpriseConfigurationV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.client_error_v2025_r0 import ClientErrorV2025R0

from box_sdk_gen.parameters.v2025_r0.box_version_header_v2025_r0 import (
    BoxVersionHeaderV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class EnterpriseConfigurationsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_enterprise_configuration_by_id_v2025_r0(
        self,
        enterprise_id: str,
        categories: List[str],
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> EnterpriseConfigurationV2025R0:
        """
                Retrieves the configuration for an enterprise.
                :param enterprise_id: The ID of the enterprise.
        Example: "3442311"
                :type enterprise_id: str
                :param categories: A comma-separated list of the enterprise configuration categories.
        Allowed values: `security`, `content_and_sharing`, `user_settings`, `shield`.
                :type categories: List[str]
                :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
                :type box_version: BoxVersionHeaderV2025R0, optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'categories': to_string(categories)}
        )
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/enterprise_configurations/',
                        to_string(enterprise_id),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, EnterpriseConfigurationV2025R0)



from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from enum import Enum

from typing import Dict

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.web_link import WebLink

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import SerializedData

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.internal.utils import DateTime


class CreateWebLinkParent(BaseObject):
    def __init__(self, id: str, **kwargs):
        """
        :param id: The ID of parent folder.
        :type id: str
        """
        super().__init__(**kwargs)
        self.id = id


class UpdateWebLinkByIdParent(BaseObject):
    def __init__(
        self, *, id: Optional[str] = None, user_id: Optional[str] = None, **kwargs
    ):
        """
        :param id: The ID of parent item., defaults to None
        :type id: Optional[str], optional
        :param user_id: The input for `user_id` is optional. Moving to non-root folder is not allowed when `user_id` is present. Parent folder id should be zero when `user_id` is provided., defaults to None
        :type user_id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.user_id = user_id


class UpdateWebLinkByIdSharedLinkAccessField(str, Enum):
    OPEN = 'open'
    COMPANY = 'company'
    COLLABORATORS = 'collaborators'


class UpdateWebLinkByIdSharedLink(BaseObject):
    def __init__(
        self,
        *,
        access: Optional[UpdateWebLinkByIdSharedLinkAccessField] = None,
        password: Optional[str] = None,
        vanity_name: Optional[str] = None,
        unshared_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
                :param access: The level of access for the shared link. This can be
        restricted to anyone with the link (`open`), only people
        within the company (`company`) and only those who
        have been invited to the folder (`collaborators`).

        If not set, this field defaults to the access level specified
        by the enterprise admin. To create a shared link with this
        default setting pass the `shared_link` object with
        no `access` field, for example `{ "shared_link": {} }`.

        The `company` access level is only available to paid
        accounts., defaults to None
                :type access: Optional[UpdateWebLinkByIdSharedLinkAccessField], optional
                :param password: The password required to access the shared link. Set the
        password to `null` to remove it.
        Passwords must now be at least eight characters
        long and include a number, upper case letter, or
        a non-numeric or non-alphabetic character.
        A password can only be set when `access` is set to `open`., defaults to None
                :type password: Optional[str], optional
                :param vanity_name: Defines a custom vanity name to use in the shared link URL,
        for example `https://app.box.com/v/my-shared-link`.

        Custom URLs should not be used when sharing sensitive content
        as vanity URLs are a lot easier to guess than regular shared
        links., defaults to None
                :type vanity_name: Optional[str], optional
                :param unshared_at: The timestamp at which this shared link will
        expire. This field can only be set by
        users with paid accounts. The value must be greater than the
        current date and time., defaults to None
                :type unshared_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.access = access
        self.password = password
        self.vanity_name = vanity_name
        self.unshared_at = unshared_at


class WebLinksManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def create_web_link(
        self,
        url: str,
        parent: CreateWebLinkParent,
        *,
        name: Optional[str] = None,
        description: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Creates a web link object within a folder.
                :param url: The URL that this web link links to. Must start with
        `"http://"` or `"https://"`.
                :type url: str
                :param parent: The parent folder to create the web link within.
                :type parent: CreateWebLinkParent
                :param name: Name of the web link. Defaults to the URL if not set., defaults to None
                :type name: Optional[str], optional
                :param description: Description of the web link., defaults to None
                :type description: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'url': url,
            'parent': parent,
            'name': name,
            'description': description,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/web_links']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)

    def get_web_link_by_id(
        self,
        web_link_id: str,
        *,
        boxapi: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Retrieve information about a web link.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param boxapi: The URL, and optional password, for the shared link of this item.

        This header can be used to access items that have not been
        explicitly shared with a user.

        Use the format `shared_link=[link]` or if a password is required then
        use `shared_link=[link]&shared_link_password=[password]`.

        This header can be used on the file or folder shared, as well as on any files
        or folders nested within the item., defaults to None
                :type boxapi: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params(
            {'boxapi': to_string(boxapi), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)

    def update_web_link_by_id(
        self,
        web_link_id: str,
        *,
        url: Optional[str] = None,
        parent: Optional[UpdateWebLinkByIdParent] = None,
        name: Optional[str] = None,
        description: Optional[str] = None,
        shared_link: Optional[UpdateWebLinkByIdSharedLink] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> WebLink:
        """
                Updates a web link object.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param url: The new URL that the web link links to. Must start with
        `"http://"` or `"https://"`., defaults to None
                :type url: Optional[str], optional
                :param name: A new name for the web link. Defaults to the URL if not set., defaults to None
                :type name: Optional[str], optional
                :param description: A new description of the web link., defaults to None
                :type description: Optional[str], optional
                :param shared_link: The settings for the shared link to update., defaults to None
                :type shared_link: Optional[UpdateWebLinkByIdSharedLink], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'url': url,
            'parent': parent,
            'name': name,
            'description': description,
            'shared_link': shared_link,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, WebLink)

    def delete_web_link_by_id(
        self,
        web_link_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a web link.
                :param web_link_id: The ID of the web link.
        Example: "12345"
                :type web_link_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/web_links/',
                        to_string(web_link_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from box_sdk_gen.box.errors import BoxSDKError


class MetadataCascadePolicyTypeField(str, Enum):
    METADATA_CASCADE_POLICY = 'metadata_cascade_policy'


class MetadataCascadePolicyOwnerEnterpriseTypeField(str, Enum):
    ENTERPRISE = 'enterprise'


class MetadataCascadePolicyOwnerEnterpriseField(BaseObject):
    _discriminator = 'type', {'enterprise'}

    def __init__(
        self,
        *,
        type: Optional[MetadataCascadePolicyOwnerEnterpriseTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: The value will always be `enterprise`., defaults to None
        :type type: Optional[MetadataCascadePolicyOwnerEnterpriseTypeField], optional
        :param id: The ID of the enterprise that owns the policy., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class MetadataCascadePolicyParentTypeField(str, Enum):
    FOLDER = 'folder'


class MetadataCascadePolicyParentField(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        *,
        type: Optional[MetadataCascadePolicyParentTypeField] = None,
        id: Optional[str] = None,
        **kwargs
    ):
        """
        :param type: The value will always be `folder`., defaults to None
        :type type: Optional[MetadataCascadePolicyParentTypeField], optional
        :param id: The ID of the folder the policy is applied to., defaults to None
        :type id: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class MetadataCascadePolicy(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'template_key': 'templateKey',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'templateKey': 'template_key',
        **BaseObject._json_to_fields_mapping,
    }
    _discriminator = 'type', {'metadata_cascade_policy'}

    def __init__(
        self,
        id: str,
        *,
        type: MetadataCascadePolicyTypeField = MetadataCascadePolicyTypeField.METADATA_CASCADE_POLICY,
        owner_enterprise: Optional[MetadataCascadePolicyOwnerEnterpriseField] = None,
        parent: Optional[MetadataCascadePolicyParentField] = None,
        scope: Optional[str] = None,
        template_key: Optional[str] = None,
        **kwargs
    ):
        """
                :param id: The ID of the metadata cascade policy object.
                :type id: str
                :param type: The value will always be `metadata_cascade_policy`., defaults to MetadataCascadePolicyTypeField.METADATA_CASCADE_POLICY
                :type type: MetadataCascadePolicyTypeField, optional
                :param owner_enterprise: The enterprise that owns this policy., defaults to None
                :type owner_enterprise: Optional[MetadataCascadePolicyOwnerEnterpriseField], optional
                :param parent: Represent the folder the policy is applied to., defaults to None
                :type parent: Optional[MetadataCascadePolicyParentField], optional
                :param scope: The scope of the metadata cascade policy can either be `global` or
        `enterprise_*`. The `global` scope is used for policies that are
        available to any Box enterprise. The `enterprise_*` scope represents
        policies that have been created within a specific enterprise, where `*`
        will be the ID of that enterprise., defaults to None
                :type scope: Optional[str], optional
                :param template_key: The key of the template that is cascaded down to the folder's
        children.

        In many cases the template key is automatically derived
        of its display name, for example `Contract Template` would
        become `contractTemplate`. In some cases the creator of the
        template will have provided its own template key.

        Please [list the templates for an enterprise][list], or
        get all instances on a [file][file] or [folder][folder]
        to inspect a template's key.

        [list]: https://developer.box.com/reference/get-metadata-templates-enterprise
        [file]: https://developer.box.com/reference/get-files-id-metadata
        [folder]: https://developer.box.com/reference/get-folders-id-metadata, defaults to None
                :type template_key: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.owner_enterprise = owner_enterprise
        self.parent = parent
        self.scope = scope
        self.template_key = template_key



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.file_request import FileRequest

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.file_request_update_request import FileRequestUpdateRequest

from box_sdk_gen.schemas.file_request_copy_request import FileRequestCopyRequest

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class UpdateFileRequestByIdStatus(str, Enum):
    ACTIVE = 'active'
    INACTIVE = 'inactive'


class CreateFileRequestCopyFolderTypeField(str, Enum):
    FOLDER = 'folder'


class CreateFileRequestCopyFolder(BaseObject):
    _discriminator = 'type', {'folder'}

    def __init__(
        self,
        id: str,
        *,
        type: Optional[CreateFileRequestCopyFolderTypeField] = None,
        **kwargs
    ):
        """
                :param id: The ID of the folder to associate the new
        file request to.
                :type id: str
                :param type: The value will always be `folder`., defaults to None
                :type type: Optional[CreateFileRequestCopyFolderTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class CreateFileRequestCopyStatus(str, Enum):
    ACTIVE = 'active'
    INACTIVE = 'inactive'


class FileRequestsManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_request_by_id(
        self,
        file_request_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileRequest:
        """
                Retrieves the information about a file request.
                :param file_request_id: The unique identifier that represent a file request.

        The ID for any file request can be determined
        by visiting a file request builder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/filerequest/123`
        the `file_request_id` is `123`.
        Example: "123"
                :type file_request_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/file_requests/',
                        to_string(file_request_id),
                    ]
                ),
                method='GET',
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileRequest)

    def update_file_request_by_id(
        self,
        file_request_id: str,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        status: Optional[UpdateFileRequestByIdStatus] = None,
        is_email_required: Optional[bool] = None,
        is_description_required: Optional[bool] = None,
        expires_at: Optional[DateTime] = None,
        if_match: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileRequest:
        """
                Updates a file request. This can be used to activate or

                deactivate a file request.

                :param file_request_id: The unique identifier that represent a file request.

        The ID for any file request can be determined
        by visiting a file request builder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/filerequest/123`
        the `file_request_id` is `123`.
        Example: "123"
                :type file_request_id: str
                :param title: An optional new title for the file request. This can be
        used to change the title of the file request.

        This will default to the value on the existing file request., defaults to None
                :type title: Optional[str], optional
                :param description: An optional new description for the file request. This can be
        used to change the description of the file request.

        This will default to the value on the existing file request., defaults to None
                :type description: Optional[str], optional
                :param status: An optional new status of the file request.

        When the status is set to `inactive`, the file request
        will no longer accept new submissions, and any visitor
        to the file request URL will receive a `HTTP 404` status
        code.

        This will default to the value on the existing file request., defaults to None
                :type status: Optional[UpdateFileRequestByIdStatus], optional
                :param is_email_required: Whether a file request submitter is required to provide
        their email address.

        When this setting is set to true, the Box UI will show
        an email field on the file request form.

        This will default to the value on the existing file request., defaults to None
                :type is_email_required: Optional[bool], optional
                :param is_description_required: Whether a file request submitter is required to provide
        a description of the files they are submitting.

        When this setting is set to true, the Box UI will show
        a description field on the file request form.

        This will default to the value on the existing file request., defaults to None
                :type is_description_required: Optional[bool], optional
                :param expires_at: The date after which a file request will no longer accept new
        submissions.

        After this date, the `status` will automatically be set to
        `inactive`.

        This will default to the value on the existing file request., defaults to None
                :type expires_at: Optional[DateTime], optional
                :param if_match: Ensures this item hasn't recently changed before
        making changes.

        Pass in the item's last observed `etag` value
        into this header and the endpoint will fail
        with a `412 Precondition Failed` if it
        has changed since., defaults to None
                :type if_match: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'title': title,
            'description': description,
            'status': status,
            'is_email_required': is_email_required,
            'is_description_required': is_description_required,
            'expires_at': expires_at,
        }
        headers_map: Dict[str, str] = prepare_params(
            {'if-match': to_string(if_match), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/file_requests/',
                        to_string(file_request_id),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileRequest)

    def delete_file_request_by_id(
        self,
        file_request_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a file request permanently.
                :param file_request_id: The unique identifier that represent a file request.

        The ID for any file request can be determined
        by visiting a file request builder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/filerequest/123`
        the `file_request_id` is `123`.
        Example: "123"
                :type file_request_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/file_requests/',
                        to_string(file_request_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None

    def create_file_request_copy(
        self,
        file_request_id: str,
        folder: CreateFileRequestCopyFolder,
        *,
        title: Optional[str] = None,
        description: Optional[str] = None,
        status: Optional[CreateFileRequestCopyStatus] = None,
        is_email_required: Optional[bool] = None,
        is_description_required: Optional[bool] = None,
        expires_at: Optional[DateTime] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FileRequest:
        """
                Copies an existing file request that is already present on one folder,

                and applies it to another folder.

                :param file_request_id: The unique identifier that represent a file request.

        The ID for any file request can be determined
        by visiting a file request builder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/filerequest/123`
        the `file_request_id` is `123`.
        Example: "123"
                :type file_request_id: str
                :param folder: The folder to associate the new file request to.
                :type folder: CreateFileRequestCopyFolder
                :param title: An optional new title for the file request. This can be
        used to change the title of the file request.

        This will default to the value on the existing file request., defaults to None
                :type title: Optional[str], optional
                :param description: An optional new description for the file request. This can be
        used to change the description of the file request.

        This will default to the value on the existing file request., defaults to None
                :type description: Optional[str], optional
                :param status: An optional new status of the file request.

        When the status is set to `inactive`, the file request
        will no longer accept new submissions, and any visitor
        to the file request URL will receive a `HTTP 404` status
        code.

        This will default to the value on the existing file request., defaults to None
                :type status: Optional[CreateFileRequestCopyStatus], optional
                :param is_email_required: Whether a file request submitter is required to provide
        their email address.

        When this setting is set to true, the Box UI will show
        an email field on the file request form.

        This will default to the value on the existing file request., defaults to None
                :type is_email_required: Optional[bool], optional
                :param is_description_required: Whether a file request submitter is required to provide
        a description of the files they are submitting.

        When this setting is set to true, the Box UI will show
        a description field on the file request form.

        This will default to the value on the existing file request., defaults to None
                :type is_description_required: Optional[bool], optional
                :param expires_at: The date after which a file request will no longer accept new
        submissions.

        After this date, the `status` will automatically be set to
        `inactive`.

        This will default to the value on the existing file request., defaults to None
                :type expires_at: Optional[DateTime], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {
            'folder': folder,
            'title': title,
            'description': description,
            'status': status,
            'is_email_required': is_email_required,
            'is_description_required': is_description_required,
            'expires_at': expires_at,
        }
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/file_requests/',
                        to_string(file_request_id),
                        '/copy',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FileRequest)



from typing import Optional

from typing import Dict

from box_sdk_gen.schemas.file_version_base import FileVersionBaseTypeField

from box_sdk_gen.schemas.file_version_base import FileVersionBase

from box_sdk_gen.box.errors import BoxSDKError


class FileVersionMini(FileVersionBase):
    _fields_to_json_mapping: Dict[str, str] = {
        'sha_1': 'sha1',
        **FileVersionBase._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'sha1': 'sha_1',
        **FileVersionBase._json_to_fields_mapping,
    }

    def __init__(
        self,
        id: str,
        *,
        sha_1: Optional[str] = None,
        type: FileVersionBaseTypeField = FileVersionBaseTypeField.FILE_VERSION,
        **kwargs
    ):
        """
        :param id: The unique identifier that represent a file version.
        :type id: str
        :param sha_1: The SHA1 hash of this version of the file., defaults to None
        :type sha_1: Optional[str], optional
        :param type: The value will always be `file_version`., defaults to FileVersionBaseTypeField.FILE_VERSION
        :type type: FileVersionBaseTypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.sha_1 = sha_1



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.comment_base import CommentBaseTypeField

from box_sdk_gen.schemas.comment_base import CommentBase

from box_sdk_gen.schemas.user_mini import UserMini

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class CommentItemField(BaseObject):
    def __init__(
        self, *, id: Optional[str] = None, type: Optional[str] = None, **kwargs
    ):
        """
        :param id: The unique identifier for this object., defaults to None
        :type id: Optional[str], optional
        :param type: The type for this object., defaults to None
        :type type: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class Comment(CommentBase):
    def __init__(
        self,
        *,
        is_reply_comment: Optional[bool] = None,
        message: Optional[str] = None,
        created_by: Optional[UserMini] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        item: Optional[CommentItemField] = None,
        id: Optional[str] = None,
        type: Optional[CommentBaseTypeField] = None,
        **kwargs
    ):
        """
                :param is_reply_comment: Whether or not this comment is a reply to another
        comment., defaults to None
                :type is_reply_comment: Optional[bool], optional
                :param message: The text of the comment, as provided by the user., defaults to None
                :type message: Optional[str], optional
                :param created_at: The time this comment was created., defaults to None
                :type created_at: Optional[DateTime], optional
                :param modified_at: The time this comment was last modified., defaults to None
                :type modified_at: Optional[DateTime], optional
                :param id: The unique identifier for this comment., defaults to None
                :type id: Optional[str], optional
                :param type: The value will always be `comment`., defaults to None
                :type type: Optional[CommentBaseTypeField], optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.is_reply_comment = is_reply_comment
        self.message = message
        self.created_by = created_by
        self.created_at = created_at
        self.modified_at = modified_at
        self.item = item



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ShieldInformationBarrierSegmentMemberBaseTypeField(str, Enum):
    SHIELD_INFORMATION_BARRIER_SEGMENT_MEMBER = (
        'shield_information_barrier_segment_member'
    )


class ShieldInformationBarrierSegmentMemberBase(BaseObject):
    _discriminator = 'type', {'shield_information_barrier_segment_member'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[ShieldInformationBarrierSegmentMemberBaseTypeField] = None,
        **kwargs
    ):
        """
                :param id: The unique identifier for the
        shield information barrier segment member., defaults to None
                :type id: Optional[str], optional
                :param type: The type of the shield information barrier segment member., defaults to None
                :type type: Optional[ShieldInformationBarrierSegmentMemberBaseTypeField], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class AiCitationTypeField(str, Enum):
    FILE = 'file'


class AiCitation(BaseObject):
    _discriminator = 'type', {'file'}

    def __init__(
        self,
        *,
        content: Optional[str] = None,
        id: Optional[str] = None,
        type: Optional[AiCitationTypeField] = None,
        name: Optional[str] = None,
        **kwargs
    ):
        """
        :param content: The specific content from where the answer was referenced., defaults to None
        :type content: Optional[str], optional
        :param id: The id of the item., defaults to None
        :type id: Optional[str], optional
        :param type: The type of the item., defaults to None
        :type type: Optional[AiCitationTypeField], optional
        :param name: The name of the item., defaults to None
        :type name: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.content = content
        self.id = id
        self.type = type
        self.name = name



from box_sdk_gen.internal.base_object import BaseObject

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.folder_locks import FolderLocks

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.folder_lock import FolderLock

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class CreateFolderLockLockedOperations(BaseObject):
    def __init__(self, move: bool, delete: bool, **kwargs):
        """
        :param move: Whether moving the folder should be locked.
        :type move: bool
        :param delete: Whether deleting the folder should be locked.
        :type delete: bool
        """
        super().__init__(**kwargs)
        self.move = move
        self.delete = delete


class CreateFolderLockFolder(BaseObject):
    def __init__(self, type: str, id: str, **kwargs):
        """
                :param type: The content type the lock is being applied to. Only `folder`
        is supported.
                :type type: str
                :param id: The ID of the folder.
                :type id: str
        """
        super().__init__(**kwargs)
        self.type = type
        self.id = id


class FolderLocksManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_folder_locks(
        self,
        folder_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FolderLocks:
        """
                Retrieves folder lock details for a given folder.

                You must be authenticated as the owner or co-owner of the folder to


                use this endpoint.

                :param folder_id: The unique identifier that represent a folder.

        The ID for any folder can be determined
        by visiting this folder in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/folder/123`
        the `folder_id` is `123`.

        The root folder of a Box account is
        always represented by the ID `0`.
                :type folder_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params(
            {'folder_id': to_string(folder_id)}
        )
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/folder_locks']
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FolderLocks)

    def create_folder_lock(
        self,
        folder: CreateFolderLockFolder,
        *,
        locked_operations: Optional[CreateFolderLockLockedOperations] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> FolderLock:
        """
                Creates a folder lock on a folder, preventing it from being moved and/or

                deleted.


                You must be authenticated as the owner or co-owner of the folder to


                use this endpoint.

                :param folder: The folder to apply the lock to.
                :type folder: CreateFolderLockFolder
                :param locked_operations: The operations to lock for the folder. If `locked_operations` is
        included in the request, both `move` and `delete` must also be
        included and both set to `true`., defaults to None
                :type locked_operations: Optional[CreateFolderLockLockedOperations], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'locked_operations': locked_operations, 'folder': folder}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [self.network_session.base_urls.base_url, '/2.0/folder_locks']
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, FolderLock)

    def delete_folder_lock_by_id(
        self,
        folder_lock_id: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a folder lock on a given folder.

                You must be authenticated as the owner or co-owner of the folder to


                use this endpoint.

                :param folder_lock_id: The ID of the folder lock.
        Example: "12345"
                :type folder_lock_id: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/folder_locks/',
                        to_string(folder_lock_id),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.task_assignment import TaskAssignment

from box_sdk_gen.box.errors import BoxSDKError


class TaskAssignments(BaseObject):
    def __init__(
        self,
        *,
        total_count: Optional[int] = None,
        entries: Optional[List[TaskAssignment]] = None,
        **kwargs
    ):
        """
        :param total_count: The total number of items in this collection., defaults to None
        :type total_count: Optional[int], optional
        :param entries: A list of task assignments., defaults to None
        :type entries: Optional[List[TaskAssignment]], optional
        """
        super().__init__(**kwargs)
        self.total_count = total_count
        self.entries = entries



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestSignerInputDateUsValidationValidationTypeField(str, Enum):
    DATE_US = 'date_us'


class SignRequestSignerInputDateUsValidation(BaseObject):
    def __init__(
        self,
        *,
        validation_type: Optional[
            SignRequestSignerInputDateUsValidationValidationTypeField
        ] = None,
        **kwargs
    ):
        """
        :param validation_type: Validates that the text input uses the US date format `MM/DD/YYYY`., defaults to None
        :type validation_type: Optional[SignRequestSignerInputDateUsValidationValidationTypeField], optional
        """
        super().__init__(**kwargs)
        self.validation_type = validation_type



from enum import Enum

from typing import Optional

from box_sdk_gen.schemas.retention_policy_base import RetentionPolicyBaseTypeField

from box_sdk_gen.schemas.retention_policy_base import RetentionPolicyBase

from box_sdk_gen.box.errors import BoxSDKError


class RetentionPolicyMiniDispositionActionField(str, Enum):
    PERMANENTLY_DELETE = 'permanently_delete'
    REMOVE_RETENTION = 'remove_retention'


class RetentionPolicyMini(RetentionPolicyBase):
    def __init__(
        self,
        id: str,
        *,
        policy_name: Optional[str] = None,
        retention_length: Optional[str] = None,
        disposition_action: Optional[RetentionPolicyMiniDispositionActionField] = None,
        type: RetentionPolicyBaseTypeField = RetentionPolicyBaseTypeField.RETENTION_POLICY,
        **kwargs
    ):
        """
                :param id: The unique identifier that represents a retention policy.
                :type id: str
                :param policy_name: The name given to the retention policy., defaults to None
                :type policy_name: Optional[str], optional
                :param retention_length: The length of the retention policy. This value
        specifies the duration in days that the retention
        policy will be active for after being assigned to
        content.  If the policy has a `policy_type` of
        `indefinite`, the `retention_length` will also be
        `indefinite`., defaults to None
                :type retention_length: Optional[str], optional
                :param disposition_action: The disposition action of the retention policy.
        This action can be `permanently_delete`, which
        will cause the content retained by the policy
        to be permanently deleted, or `remove_retention`,
        which will lift the retention policy from the content,
        allowing it to be deleted by users,
        once the retention policy has expired., defaults to None
                :type disposition_action: Optional[RetentionPolicyMiniDispositionActionField], optional
                :param type: The value will always be `retention_policy`., defaults to RetentionPolicyBaseTypeField.RETENTION_POLICY
                :type type: RetentionPolicyBaseTypeField, optional
        """
        super().__init__(id=id, type=type, **kwargs)
        self.policy_name = policy_name
        self.retention_length = retention_length
        self.disposition_action = disposition_action



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class ShieldRuleItemV2025R0TypeField(str, Enum):
    SHIELD_RULE = 'shield_rule'


class ShieldRuleItemV2025R0PriorityField(str, Enum):
    INFORMATIONAL = 'informational'
    LOW = 'low'
    MEDIUM = 'medium'
    HIGH = 'high'
    CRITICAL = 'critical'


class ShieldRuleItemV2025R0(BaseObject):
    _discriminator = 'type', {'shield_rule'}

    def __init__(
        self,
        *,
        id: Optional[str] = None,
        type: Optional[ShieldRuleItemV2025R0TypeField] = None,
        rule_category: Optional[str] = None,
        name: Optional[str] = None,
        description: Optional[str] = None,
        priority: Optional[ShieldRuleItemV2025R0PriorityField] = None,
        created_at: Optional[DateTime] = None,
        modified_at: Optional[DateTime] = None,
        **kwargs
    ):
        """
        :param id: The identifier of the shield rule., defaults to None
        :type id: Optional[str], optional
        :param type: The value will always be `shield_rule`., defaults to None
        :type type: Optional[ShieldRuleItemV2025R0TypeField], optional
        :param rule_category: The category of the shield rule., defaults to None
        :type rule_category: Optional[str], optional
        :param name: The name of the shield rule., defaults to None
        :type name: Optional[str], optional
        :param description: The description of the shield rule., defaults to None
        :type description: Optional[str], optional
        :param priority: The priority level of the shield rule., defaults to None
        :type priority: Optional[ShieldRuleItemV2025R0PriorityField], optional
        :param created_at: The date and time when the shield rule was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_at: The date and time when the shield rule was last modified., defaults to None
        :type modified_at: Optional[DateTime], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.rule_category = rule_category
        self.name = name
        self.description = description
        self.priority = priority
        self.created_at = created_at
        self.modified_at = modified_at



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SignRequestSignerInputCustomValidationValidationTypeField(str, Enum):
    CUSTOM = 'custom'


class SignRequestSignerInputCustomValidation(BaseObject):
    def __init__(
        self,
        *,
        validation_type: SignRequestSignerInputCustomValidationValidationTypeField = SignRequestSignerInputCustomValidationValidationTypeField.CUSTOM,
        custom_regex: Optional[str] = None,
        custom_error_message: Optional[str] = None,
        **kwargs
    ):
        """
                :param validation_type: Defines the validation format for the text input as custom.
        A custom regular expression is used for validation., defaults to SignRequestSignerInputCustomValidationValidationTypeField.CUSTOM
                :type validation_type: SignRequestSignerInputCustomValidationValidationTypeField, optional
                :param custom_regex: Regular expression used for validation., defaults to None
                :type custom_regex: Optional[str], optional
                :param custom_error_message: Error message shown if input fails custom regular expression validation., defaults to None
                :type custom_error_message: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.validation_type = validation_type
        self.custom_regex = custom_regex
        self.custom_error_message = custom_error_message



from enum import Enum

from typing import Optional

from typing import List

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.group_base import GroupBase

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.schemas.ai_agent_allowed_entity import AiAgentAllowedEntity

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.internal.utils import DateTime


class AiSingleAgentResponseTypeField(str, Enum):
    AI_AGENT = 'ai_agent'


class AiSingleAgentResponse(BaseObject):
    _discriminator = 'type', {'ai_agent'}

    def __init__(
        self,
        id: str,
        origin: str,
        name: str,
        access_state: str,
        *,
        type: Optional[AiSingleAgentResponseTypeField] = None,
        created_by: Optional[UserBase] = None,
        created_at: Optional[DateTime] = None,
        modified_by: Optional[UserBase] = None,
        modified_at: Optional[DateTime] = None,
        icon_reference: Optional[str] = None,
        allowed_entities: Optional[List[AiAgentAllowedEntity]] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier of the AI Agent.
        :type id: str
        :param origin: The provider of the AI Agent.
        :type origin: str
        :param name: The name of the AI Agent.
        :type name: str
        :param access_state: The state of the AI Agent. Possible values are: `enabled`, `disabled`, and `enabled_for_selected_users`.
        :type access_state: str
        :param type: The type of agent used to handle queries., defaults to None
        :type type: Optional[AiSingleAgentResponseTypeField], optional
        :param created_by: The user who created this agent., defaults to None
        :type created_by: Optional[UserBase], optional
        :param created_at: The ISO date-time formatted timestamp of when this AI agent was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_by: The user who most recently modified this agent., defaults to None
        :type modified_by: Optional[UserBase], optional
        :param modified_at: The ISO date-time formatted timestamp of when this AI agent was recently modified., defaults to None
        :type modified_at: Optional[DateTime], optional
        :param icon_reference: The icon reference of the AI Agent., defaults to None
        :type icon_reference: Optional[str], optional
        :param allowed_entities: List of allowed users or groups., defaults to None
        :type allowed_entities: Optional[List[AiAgentAllowedEntity]], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.origin = origin
        self.name = name
        self.access_state = access_state
        self.type = type
        self.created_by = created_by
        self.created_at = created_at
        self.modified_by = modified_by
        self.modified_at = modified_at
        self.icon_reference = icon_reference
        self.allowed_entities = allowed_entities



from typing import Optional

from typing import List

from box_sdk_gen.schemas.ai_single_agent_response import AiSingleAgentResponseTypeField

from box_sdk_gen.schemas.user_base import UserBase

from box_sdk_gen.internal.utils import DateTime

from box_sdk_gen.schemas.group_base import GroupBase

from box_sdk_gen.schemas.ai_agent_allowed_entity import AiAgentAllowedEntity

from box_sdk_gen.schemas.ai_single_agent_response import AiSingleAgentResponse

from box_sdk_gen.schemas.ai_studio_agent_ask_response import AiStudioAgentAskResponse

from box_sdk_gen.schemas.ai_studio_agent_text_gen_response import (
    AiStudioAgentTextGenResponse,
)

from box_sdk_gen.schemas.ai_studio_agent_extract_response import (
    AiStudioAgentExtractResponse,
)

from box_sdk_gen.box.errors import BoxSDKError


class AiSingleAgentResponseFull(AiSingleAgentResponse):
    def __init__(
        self,
        id: str,
        origin: str,
        name: str,
        access_state: str,
        *,
        ask: Optional[AiStudioAgentAskResponse] = None,
        text_gen: Optional[AiStudioAgentTextGenResponse] = None,
        extract: Optional[AiStudioAgentExtractResponse] = None,
        type: Optional[AiSingleAgentResponseTypeField] = None,
        created_by: Optional[UserBase] = None,
        created_at: Optional[DateTime] = None,
        modified_by: Optional[UserBase] = None,
        modified_at: Optional[DateTime] = None,
        icon_reference: Optional[str] = None,
        allowed_entities: Optional[List[AiAgentAllowedEntity]] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier of the AI Agent.
        :type id: str
        :param origin: The provider of the AI Agent.
        :type origin: str
        :param name: The name of the AI Agent.
        :type name: str
        :param access_state: The state of the AI Agent. Possible values are: `enabled`, `disabled`, and `enabled_for_selected_users`.
        :type access_state: str
        :param type: The type of agent used to handle queries., defaults to None
        :type type: Optional[AiSingleAgentResponseTypeField], optional
        :param created_by: The user who created this agent., defaults to None
        :type created_by: Optional[UserBase], optional
        :param created_at: The ISO date-time formatted timestamp of when this AI agent was created., defaults to None
        :type created_at: Optional[DateTime], optional
        :param modified_by: The user who most recently modified this agent., defaults to None
        :type modified_by: Optional[UserBase], optional
        :param modified_at: The ISO date-time formatted timestamp of when this AI agent was recently modified., defaults to None
        :type modified_at: Optional[DateTime], optional
        :param icon_reference: The icon reference of the AI Agent., defaults to None
        :type icon_reference: Optional[str], optional
        :param allowed_entities: List of allowed users or groups., defaults to None
        :type allowed_entities: Optional[List[AiAgentAllowedEntity]], optional
        """
        super().__init__(
            id=id,
            origin=origin,
            name=name,
            access_state=access_state,
            type=type,
            created_by=created_by,
            created_at=created_at,
            modified_by=modified_by,
            modified_at=modified_at,
            icon_reference=icon_reference,
            allowed_entities=allowed_entities,
            **kwargs
        )
        self.ask = ask
        self.text_gen = text_gen
        self.extract = extract



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class AiItemAskTypeField(str, Enum):
    FILE = 'file'
    HUBS = 'hubs'


class AiItemAsk(BaseObject):
    _discriminator = 'type', {'file', 'hubs'}

    def __init__(
        self,
        id: str,
        type: AiItemAskTypeField,
        *,
        content: Optional[str] = None,
        **kwargs
    ):
        """
        :param id: The ID of the file.
        :type id: str
        :param type: The type of the item. A `hubs` item must be used as a single item.
        :type type: AiItemAskTypeField
        :param content: The content of the item, often the text representation., defaults to None
        :type content: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.content = content



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.integration_mapping_partner_item_slack import (
    IntegrationMappingPartnerItemSlack,
)

from box_sdk_gen.schemas.integration_mapping_box_item_slack import (
    IntegrationMappingBoxItemSlack,
)

from box_sdk_gen.schemas.integration_mapping_slack_options import (
    IntegrationMappingSlackOptions,
)

from box_sdk_gen.box.errors import BoxSDKError


class IntegrationMappingSlackCreateRequest(BaseObject):
    def __init__(
        self,
        partner_item: IntegrationMappingPartnerItemSlack,
        box_item: IntegrationMappingBoxItemSlack,
        *,
        options: Optional[IntegrationMappingSlackOptions] = None,
        **kwargs
    ):
        super().__init__(**kwargs)
        self.partner_item = partner_item
        self.box_item = box_item
        self.options = options



from enum import Enum

from typing import Optional

from typing import Dict

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.serialization.json import serialize

from typing import List

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.metadatas import Metadatas

from box_sdk_gen.schemas.client_error import ClientError

from box_sdk_gen.schemas.metadata_full import MetadataFull

from box_sdk_gen.schemas.metadata_error import MetadataError

from box_sdk_gen.schemas.metadata_instance_value import MetadataInstanceValue

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class GetFileMetadataByIdScope(str, Enum):
    GLOBAL = 'global'
    ENTERPRISE = 'enterprise'


class CreateFileMetadataByIdScope(str, Enum):
    GLOBAL = 'global'
    ENTERPRISE = 'enterprise'


class UpdateFileMetadataByIdScope(str, Enum):
    GLOBAL = 'global'
    ENTERPRISE = 'enterprise'


class UpdateFileMetadataByIdRequestBodyOpField(str, Enum):
    ADD = 'add'
    REPLACE = 'replace'
    REMOVE = 'remove'
    TEST = 'test'
    MOVE = 'move'
    COPY = 'copy'


class UpdateFileMetadataByIdRequestBody(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'from_': 'from',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'from': 'from_',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        op: Optional[UpdateFileMetadataByIdRequestBodyOpField] = None,
        path: Optional[str] = None,
        value: Optional[MetadataInstanceValue] = None,
        from_: Optional[str] = None,
        **kwargs
    ):
        """
                :param op: The type of change to perform on the template. Some
        of these are hazardous as they will change existing templates., defaults to None
                :type op: Optional[UpdateFileMetadataByIdRequestBodyOpField], optional
                :param path: The location in the metadata JSON object
        to apply the changes to, in the format of a
        [JSON-Pointer](https://tools.ietf.org/html/rfc6901).

        The path must always be prefixed with a `/` to represent the root
        of the template. The characters `~` and `/` are reserved
        characters and must be escaped in the key., defaults to None
                :type path: Optional[str], optional
                :param from_: The location in the metadata JSON object to move or copy a value
        from. Required for `move` or `copy` operations and must be in the
        format of a [JSON-Pointer](https://tools.ietf.org/html/rfc6901)., defaults to None
                :type from_: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.op = op
        self.path = path
        self.value = value
        self.from_ = from_


class DeleteFileMetadataByIdScope(str, Enum):
    GLOBAL = 'global'
    ENTERPRISE = 'enterprise'


class FileMetadataManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def get_file_metadata(
        self,
        file_id: str,
        *,
        view: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> Metadatas:
        """
                Retrieves all metadata for a given file.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param view: Taxonomy field values are returned in `API view` by default, meaning
        the value is represented with a taxonomy node identifier.
        To retrieve the `Hydrated view`, where taxonomy values are represented
        with the full taxonomy node information, set this parameter to `hydrated`.
        This is the only supported value for this parameter., defaults to None
                :type view: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'view': to_string(view)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata',
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, Metadatas)

    def get_file_metadata_by_id(
        self,
        file_id: str,
        scope: GetFileMetadataByIdScope,
        template_key: str,
        *,
        view: Optional[str] = None,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataFull:
        """
                Retrieves the instance of a metadata template that has been applied to a

                file.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param scope: The scope of the metadata template.
        Example: "global"
                :type scope: GetFileMetadataByIdScope
                :param template_key: The name of the metadata template.
        Example: "properties"
                :type template_key: str
                :param view: Taxonomy field values are returned in `API view` by default, meaning
        the value is represented with a taxonomy node identifier.
        To retrieve the `Hydrated view`, where taxonomy values are represented
        with the full taxonomy node information, set this parameter to `hydrated`.
        This is the only supported value for this parameter., defaults to None
                :type view: Optional[str], optional
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        query_params_map: Dict[str, str] = prepare_params({'view': to_string(view)})
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/',
                        to_string(scope),
                        '/',
                        to_string(template_key),
                    ]
                ),
                method='GET',
                params=query_params_map,
                headers=headers_map,
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataFull)

    def create_file_metadata_by_id(
        self,
        file_id: str,
        scope: CreateFileMetadataByIdScope,
        template_key: str,
        request_body: Dict,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataFull:
        """
                Applies an instance of a metadata template to a file.

                In most cases only values that are present in the metadata template


                will be accepted, except for the `global.properties` template which accepts


                any key-value pair.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param scope: The scope of the metadata template.
        Example: "global"
                :type scope: CreateFileMetadataByIdScope
                :param template_key: The name of the metadata template.
        Example: "properties"
                :type template_key: str
                :param request_body: Request body of createFileMetadataById method
                :type request_body: Dict
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/',
                        to_string(scope),
                        '/',
                        to_string(template_key),
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataFull)

    def update_file_metadata_by_id(
        self,
        file_id: str,
        scope: UpdateFileMetadataByIdScope,
        template_key: str,
        request_body: List[UpdateFileMetadataByIdRequestBody],
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> MetadataFull:
        """
                Updates a piece of metadata on a file.

                The metadata instance can only be updated if the template has already been


                applied to the file before. When editing metadata, only values that match


                the metadata template schema will be accepted.


                The update is applied atomically. If any errors occur during the


                application of the operations, the metadata instance will not be changed.

                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param scope: The scope of the metadata template.
        Example: "global"
                :type scope: UpdateFileMetadataByIdScope
                :param template_key: The name of the metadata template.
        Example: "properties"
                :type template_key: str
                :param request_body: Request body of updateFileMetadataById method
                :type request_body: List[UpdateFileMetadataByIdRequestBody]
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/',
                        to_string(scope),
                        '/',
                        to_string(template_key),
                    ]
                ),
                method='PUT',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json-patch+json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, MetadataFull)

    def delete_file_metadata_by_id(
        self,
        file_id: str,
        scope: DeleteFileMetadataByIdScope,
        template_key: str,
        *,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> None:
        """
                Deletes a piece of file metadata.
                :param file_id: The unique identifier that represents a file.

        The ID for any file can be determined
        by visiting a file in the web application
        and copying the ID from the URL. For example,
        for the URL `https://*.app.box.com/files/123`
        the `file_id` is `123`.
        Example: "12345"
                :type file_id: str
                :param scope: The scope of the metadata template.
        Example: "global"
                :type scope: DeleteFileMetadataByIdScope
                :param template_key: The name of the metadata template.
        Example: "properties"
                :type template_key: str
                :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
                :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        headers_map: Dict[str, str] = prepare_params({**extra_headers})
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/files/',
                        to_string(file_id),
                        '/metadata/',
                        to_string(scope),
                        '/',
                        to_string(template_key),
                    ]
                ),
                method='DELETE',
                headers=headers_map,
                response_format=ResponseFormat.NO_CONTENT,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return None



from typing import Optional

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_base_v2025_r0 import (
    DocGenJobBaseV2025R0TypeField,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_base_v2025_r0 import DocGenJobBaseV2025R0

from box_sdk_gen.schemas.v2025_r0.doc_gen_batch_base_v2025_r0 import (
    DocGenBatchBaseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.file_reference_v2025_r0 import FileReferenceV2025R0

from box_sdk_gen.schemas.v2025_r0.file_version_base_v2025_r0 import (
    FileVersionBaseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_v2025_r0 import (
    DocGenJobV2025R0StatusField,
)

from box_sdk_gen.schemas.v2025_r0.doc_gen_job_v2025_r0 import DocGenJobV2025R0

from box_sdk_gen.schemas.v2025_r0.user_base_v2025_r0 import UserBaseV2025R0

from box_sdk_gen.schemas.v2025_r0.enterprise_reference_v2025_r0 import (
    EnterpriseReferenceV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError


class DocGenJobFullV2025R0(DocGenJobV2025R0):
    def __init__(
        self,
        created_by: UserBaseV2025R0,
        enterprise: EnterpriseReferenceV2025R0,
        source: str,
        batch: DocGenBatchBaseV2025R0,
        template_file: FileReferenceV2025R0,
        template_file_version: FileVersionBaseV2025R0,
        status: DocGenJobV2025R0StatusField,
        output_type: str,
        id: str,
        *,
        created_at: Optional[str] = None,
        output_file: Optional[FileReferenceV2025R0] = None,
        output_file_version: Optional[FileVersionBaseV2025R0] = None,
        type: DocGenJobBaseV2025R0TypeField = DocGenJobBaseV2025R0TypeField.DOCGEN_JOB,
        **kwargs
    ):
        """
        :param source: Source of the request.
        :type source: str
        :param status: Status of the job.
        :type status: DocGenJobV2025R0StatusField
        :param output_type: Type of the generated file.
        :type output_type: str
        :param id: The unique identifier that represent a Box Doc Gen job.
        :type id: str
        :param created_at: Time of job creation., defaults to None
        :type created_at: Optional[str], optional
        :param type: The value will always be `docgen_job`., defaults to DocGenJobBaseV2025R0TypeField.DOCGEN_JOB
        :type type: DocGenJobBaseV2025R0TypeField, optional
        """
        super().__init__(
            batch=batch,
            template_file=template_file,
            template_file_version=template_file_version,
            status=status,
            output_type=output_type,
            id=id,
            output_file=output_file,
            output_file_version=output_file_version,
            type=type,
            **kwargs
        )
        self.created_by = created_by
        self.enterprise = enterprise
        self.source = source
        self.created_at = created_at



from typing import Optional

from typing import Dict

from box_sdk_gen.schemas.upload_part_mini import UploadPartMini

from box_sdk_gen.box.errors import BoxSDKError


class UploadPart(UploadPartMini):
    _fields_to_json_mapping: Dict[str, str] = {
        'sha_1': 'sha1',
        **UploadPartMini._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'sha1': 'sha_1',
        **UploadPartMini._json_to_fields_mapping,
    }

    def __init__(
        self,
        *,
        sha_1: Optional[str] = None,
        part_id: Optional[str] = None,
        offset: Optional[int] = None,
        size: Optional[int] = None,
        **kwargs
    ):
        """
                :param sha_1: The SHA1 hash of the chunk., defaults to None
                :type sha_1: Optional[str], optional
                :param part_id: The unique ID of the chunk., defaults to None
                :type part_id: Optional[str], optional
                :param offset: The offset of the chunk within the file
        in bytes. The lower bound of the position
        of the chunk within the file., defaults to None
                :type offset: Optional[int], optional
                :param size: The size of the chunk in bytes., defaults to None
                :type size: Optional[int], optional
        """
        super().__init__(part_id=part_id, offset=offset, size=size, **kwargs)
        self.sha_1 = sha_1



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.schemas.storage_policy_mini import StoragePolicyMini

from box_sdk_gen.box.errors import BoxSDKError


class StoragePolicyAssignmentTypeField(str, Enum):
    STORAGE_POLICY_ASSIGNMENT = 'storage_policy_assignment'


class StoragePolicyAssignmentAssignedToField(BaseObject):
    def __init__(
        self, *, id: Optional[str] = None, type: Optional[str] = None, **kwargs
    ):
        """
        :param id: The unique identifier for this object., defaults to None
        :type id: Optional[str], optional
        :param type: The type for this object., defaults to None
        :type type: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type


class StoragePolicyAssignment(BaseObject):
    _discriminator = 'type', {'storage_policy_assignment'}

    def __init__(
        self,
        id: str,
        *,
        type: StoragePolicyAssignmentTypeField = StoragePolicyAssignmentTypeField.STORAGE_POLICY_ASSIGNMENT,
        storage_policy: Optional[StoragePolicyMini] = None,
        assigned_to: Optional[StoragePolicyAssignmentAssignedToField] = None,
        **kwargs
    ):
        """
        :param id: The unique identifier for a storage policy assignment.
        :type id: str
        :param type: The value will always be `storage_policy_assignment`., defaults to StoragePolicyAssignmentTypeField.STORAGE_POLICY_ASSIGNMENT
        :type type: StoragePolicyAssignmentTypeField, optional
        """
        super().__init__(**kwargs)
        self.id = id
        self.type = type
        self.storage_policy = storage_policy
        self.assigned_to = assigned_to



from typing import Optional

from typing import List

from typing import Dict

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.serialization.json import serialize

from box_sdk_gen.serialization.json import deserialize

from box_sdk_gen.schemas.v2025_r0.user_reference_v2025_r0 import UserReferenceV2025R0

from box_sdk_gen.networking.fetch_options import ResponseFormat

from box_sdk_gen.schemas.v2025_r0.external_users_submit_delete_job_response_v2025_r0 import (
    ExternalUsersSubmitDeleteJobResponseV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.client_error_v2025_r0 import ClientErrorV2025R0

from box_sdk_gen.parameters.v2025_r0.box_version_header_v2025_r0 import (
    BoxVersionHeaderV2025R0,
)

from box_sdk_gen.schemas.v2025_r0.external_users_submit_delete_job_request_v2025_r0 import (
    ExternalUsersSubmitDeleteJobRequestV2025R0,
)

from box_sdk_gen.box.errors import BoxSDKError

from box_sdk_gen.networking.auth import Authentication

from box_sdk_gen.networking.network import NetworkSession

from box_sdk_gen.networking.fetch_options import FetchOptions

from box_sdk_gen.networking.fetch_response import FetchResponse

from box_sdk_gen.internal.utils import prepare_params

from box_sdk_gen.internal.utils import to_string

from box_sdk_gen.internal.utils import ByteStream

from box_sdk_gen.serialization.json import sd_to_json

from box_sdk_gen.serialization.json import SerializedData


class ExternalUsersManager:
    def __init__(
        self,
        *,
        auth: Optional[Authentication] = None,
        network_session: NetworkSession = None
    ):
        if network_session is None:
            network_session = NetworkSession()
        self.auth = auth
        self.network_session = network_session

    def submit_job_to_delete_external_users_v2025_r0(
        self,
        external_users: List[UserReferenceV2025R0],
        *,
        box_version: BoxVersionHeaderV2025R0 = BoxVersionHeaderV2025R0._2025_0,
        extra_headers: Optional[Dict[str, Optional[str]]] = None
    ) -> ExternalUsersSubmitDeleteJobResponseV2025R0:
        """
        Delete external users from current user enterprise. This will remove each

        external user from all invited collaborations within the current enterprise.

        :param external_users: List of external users to delete.
        :type external_users: List[UserReferenceV2025R0]
        :param box_version: Version header., defaults to BoxVersionHeaderV2025R0._2025_0
        :type box_version: BoxVersionHeaderV2025R0, optional
        :param extra_headers: Extra headers that will be included in the HTTP request., defaults to None
        :type extra_headers: Optional[Dict[str, Optional[str]]], optional
        """
        if extra_headers is None:
            extra_headers = {}
        request_body: Dict = {'external_users': external_users}
        headers_map: Dict[str, str] = prepare_params(
            {'box-version': to_string(box_version), **extra_headers}
        )
        response: FetchResponse = self.network_session.network_client.fetch(
            FetchOptions(
                url=''.join(
                    [
                        self.network_session.base_urls.base_url,
                        '/2.0/external_users/submit_delete_job',
                    ]
                ),
                method='POST',
                headers=headers_map,
                data=serialize(request_body),
                content_type='application/json',
                response_format=ResponseFormat.JSON,
                auth=self.auth,
                network_session=self.network_session,
            )
        )
        return deserialize(response.data, ExternalUsersSubmitDeleteJobResponseV2025R0)



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class ExternalUserDeletionResultV2025R0(BaseObject):
    def __init__(
        self, user_id: str, status: int, *, detail: Optional[str] = None, **kwargs
    ):
        """
        :param user_id: The ID of the external user.
        :type user_id: str
        :param status: HTTP status code for a specific user's deletion request.
        :type status: int
        :param detail: Deletion request status details. This property is only present when the deletion request is not successful., defaults to None
        :type detail: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.user_id = user_id
        self.status = status
        self.detail = detail



from enum import Enum

from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from typing import Dict

from typing import List

from box_sdk_gen.box.errors import BoxSDKError


class MetadataQueryOrderByDirectionField(str, Enum):
    ASC = 'ASC'
    DESC = 'DESC'


class MetadataQueryOrderByField(BaseObject):
    def __init__(
        self,
        *,
        field_key: Optional[str] = None,
        direction: Optional[MetadataQueryOrderByDirectionField] = None,
        **kwargs
    ):
        """
                :param field_key: The metadata template field to order by.

        The `field_key` represents the `key` value of a field from the
        metadata template being searched for., defaults to None
                :type field_key: Optional[str], optional
                :param direction: The direction to order by, either ascending or descending.

        The `ordering` direction must be the same for each item in the
        array., defaults to None
                :type direction: Optional[MetadataQueryOrderByDirectionField], optional
        """
        super().__init__(**kwargs)
        self.field_key = field_key
        self.direction = direction


class MetadataQuery(BaseObject):
    _fields_to_json_mapping: Dict[str, str] = {
        'from_': 'from',
        **BaseObject._fields_to_json_mapping,
    }
    _json_to_fields_mapping: Dict[str, str] = {
        'from': 'from_',
        **BaseObject._json_to_fields_mapping,
    }

    def __init__(
        self,
        from_: str,
        ancestor_folder_id: str,
        *,
        query: Optional[str] = None,
        query_params: Optional[Dict] = None,
        order_by: Optional[List[MetadataQueryOrderByField]] = None,
        limit: Optional[int] = None,
        marker: Optional[str] = None,
        fields: Optional[List[str]] = None,
        **kwargs
    ):
        """
                :param from_: Specifies the template used in the query. Must be in the form
        `scope.templateKey`. Not all templates can be used in this field,
        most notably the built-in, Box-provided classification templates
        can not be used in a query.
                :type from_: str
                :param ancestor_folder_id: The ID of the folder that you are restricting the query to. A
        value of zero will return results from all folders you have access
        to. A non-zero value will only return results found in the folder
        corresponding to the ID or in any of its subfolders.
                :type ancestor_folder_id: str
                :param query: The query to perform. A query is a logical expression that is very similar
        to a SQL `SELECT` statement. Values in the search query can be turned into
        parameters specified in the `query_param` arguments list to prevent having
        to manually insert search values into the query string.

        For example, a value of `:amount` would represent the `amount` value in
        `query_params` object., defaults to None
                :type query: Optional[str], optional
                :param query_params: Set of arguments corresponding to the parameters specified in the
        `query`. The type of each parameter used in the `query_params` must match
        the type of the corresponding metadata template field., defaults to None
                :type query_params: Optional[Dict], optional
                :param order_by: A list of template fields and directions to sort the metadata query
        results by.

        The ordering `direction` must be the same for each item in the array., defaults to None
                :type order_by: Optional[List[MetadataQueryOrderByField]], optional
                :param limit: A value between 0 and 100 that indicates the maximum number of results
        to return for a single request. This only specifies a maximum
        boundary and will not guarantee the minimum number of results
        returned., defaults to None
                :type limit: Optional[int], optional
                :param marker: Marker to use for requesting the next page., defaults to None
                :type marker: Optional[str], optional
                :param fields: By default, this endpoint returns only the most basic info about the items for
        which the query matches. This attribute can be used to specify a list of
        additional attributes to return for any item, including its metadata.

        This attribute takes a list of item fields, metadata template identifiers,
        or metadata template field identifiers.

        For example:

        * `created_by` will add the details of the user who created the item to
        the response.
        * `metadata.<scope>.<templateKey>` will return the mini-representation
        of the metadata instance identified by the `scope` and `templateKey`.
        * `metadata.<scope>.<templateKey>.<field>` will return all the mini-representation
        of the metadata instance identified by the `scope` and `templateKey` plus
        the field specified by the `field` name. Multiple fields for the same
        `scope` and `templateKey` can be defined., defaults to None
                :type fields: Optional[List[str]], optional
        """
        super().__init__(**kwargs)
        self.from_ = from_
        self.ancestor_folder_id = ancestor_folder_id
        self.query = query
        self.query_params = query_params
        self.order_by = order_by
        self.limit = limit
        self.marker = marker
        self.fields = fields



from typing import Union

from typing import Dict

from box_sdk_gen.schemas.user import User

from box_sdk_gen.schemas.event_source import EventSource

from box_sdk_gen.schemas.file import File

from box_sdk_gen.schemas.folder import Folder

from box_sdk_gen.schemas.app_item_event_source import AppItemEventSource

from box_sdk_gen.box.errors import BoxSDKError

EventSourceResource = Union[User, EventSource, File, Folder, Dict, AppItemEventSource]



from typing import Optional

from box_sdk_gen.internal.base_object import BaseObject

from box_sdk_gen.box.errors import BoxSDKError


class SharedLinkPermissionsV2025R0(BaseObject):
    def __init__(
        self,
        *,
        shared_links_option: Optional[str] = None,
        default_shared_link_type: Optional[str] = None,
        notes_shared_link_option: Optional[str] = None,
        default_notes_shared_link_type: Optional[str] = None,
        **kwargs
    ):
        """
        :param shared_links_option: The selected option for shared links permissions., defaults to None
        :type shared_links_option: Optional[str], optional
        :param default_shared_link_type: The default shared link type., defaults to None
        :type default_shared_link_type: Optional[str], optional
        :param notes_shared_link_option: The selected option for notes shared links permissions., defaults to None
        :type notes_shared_link_option: Optional[str], optional
        :param default_notes_shared_link_type: The default notes shared link type., defaults to None
        :type default_notes_shared_link_type: Optional[str], optional
        """
        super().__init__(**kwargs)
        self.shared_links_option = shared_links_option
        self.default_shared_link_type = default_shared_link_type
        self.notes_shared_link_option = notes_shared_link_option
        self.default_notes_shared_link_type = default_notes_shared_link_type
